@@ -1,3 +1,4 @@
+import time
 import zipfile
 from osgeo import gdal
 from pathlib import Path
@@ -56,8 +57,11 @@ def extract(zip_path, project_dir, extract_dict):
 
     extracted_paths.sort()
 
-    _rm_tree(project_dir/f"{zip_path.stem}.SAFE")
-
+    try: 
+        _rm_tree(project_dir/f"{zip_path.stem}.SAFE")
+    except:
+        print(f"No folder found to remove at {project_dir/f'{zip_path.stem}.SAFE'}")
+        
     return extracted_paths
 
 def download_dem(s2_path, out_dir):
@@ -118,28 +122,37 @@ def tile(*raster_paths, tile_size=244, data_type="stacked"):
     return tile_dir
 
 def run_default_preprocessing(project_dir, s2_zip_path, extract_dict=None, delete_all=True):
+    Mtic, mtic = time.time(), time.time()
     
+    print(f"o---o---o---o---o---o---o\tNot Started \t\t\t(0/7 - {time.time()-mtic:.2f}s|{time.time()-Mtic:.2f}s)")
     if extract_dict is None:
         extract_dict = EXTRACT_DICT
     s2_paths_list = extract(s2_zip_path, project_dir, extract_dict)
     target_raster_path = s2_paths_list[0]
-    print("Sentinel-2 rasters extracted.")
+    print(f"•---o---o---o---o---o---o\tSentinel bands extracted \t(1/7 - {time.time()-mtic:.2f}s|{time.time()-Mtic:.2f}s)")
+    mtic=time.time()
 
     dem_path = download_dem(target_raster_path, project_dir)
-    print("DEM downloaded.")
+    print(f"•---•---o---o---o---o---o\tDEM downloaded \t\t\t(2/7 - {time.time()-mtic:.2f}s|{time.time()-Mtic:.2f}s)")
+    mtic=time.time()
     dem_path = clip_dem(dem_path, target_raster_path, project_dir)
+    print(f"•---•---•---o---o---o---o\tDEM clipped \t\t\t(3/7 - {time.time()-mtic:.2f}s|{time.time()-Mtic:.2f}s)")
+    mtic=time.time()
     dem_paths_list = process_dem(dem_path, project_dir)
     all_paths_list = s2_paths_list + dem_paths_list
-    print("DEM clipped.")
+    print(f"•---•---•---•---o---o---o\tDEM processed \t\t\t(4/7 - {time.time()-mtic:.2f}s|{time.time()-Mtic:.2f}s)")
+    mtic=time.time()
 
     reprojected_raster_paths = reproject(*all_paths_list, target_raster_path = target_raster_path)
-    print("All rasters reprojected.")
+    print(f"•---•---•---•---•---o---o\tReprojections completed \t(5/7 - {time.time()-mtic:.2f}s|{time.time()-Mtic:.2f}s)")
+    mtic=time.time()
 
     stacked_path = stack(project_dir, *reprojected_raster_paths)
-    print("All rasters stacked.")
+    print(f"•---•---•---•---•---•---o\tAll bands stacked \t\t(6/7 - {time.time()-mtic:.2f}s|{time.time()-Mtic:.2f}s)")
+    mtic=time.time()
     
     tile_dir = tile(stacked_path)
-    print("Tiling completed.")
+    print(f"•---•---•---•---•---•---•\tTiles ready for inference \t(7/7 - {time.time()-mtic:.2f}s|{time.time()-Mtic:.2f}s)")
 
     if delete_all:
         for s2_path in s2_paths_list:
